==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/BridgeBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.BridgeBody;
import io.ciera.tool.sql.ooaofooa.body.BridgeBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;

import java.util.Arrays;
import java.util.List;


public class BridgeBodySetImpl extends InstanceSet<BridgeBodySet,BridgeBody> implements BridgeBodySet {

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( BridgeBody bridgebody : this ) bridgebody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( BridgeBody bridgebody : this ) bridgebody.setBrg_ID( ref_Brg_ID );
    }


    // selections
    @Override
    public BridgeSet R697_specifies_processing_for_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( BridgeBody bridgebody : this ) bridgeset.add( bridgebody.R697_specifies_processing_for_Bridge() );
        return bridgeset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( BridgeBody bridgebody : this ) bodyset.add( bridgebody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public BridgeBody nullElement() {
        return BridgeBodyImpl.EMPTY_BRIDGEBODY;
    }

    @Override
    public BridgeBodySet emptySet() {
      return new BridgeBodySetImpl();
    }

    @Override
    public BridgeBodySet value() {
        return this;
    }

    @Override
    public List<BridgeBody> elements() {
        return Arrays.asList(toArray(new BridgeBody[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/body/impl/BridgeBodySetImpl.java <==
package io.ciera.tool.sql.ooaofooa.body.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.BodySet;
import io.ciera.tool.sql.ooaofooa.body.BridgeBody;
import io.ciera.tool.sql.ooaofooa.body.BridgeBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.BodySetImpl;
import io.ciera.tool.sql.ooaofooa.domain.BridgeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BridgeBodySetImpl extends InstanceSet<BridgeBodySet,BridgeBody> implements BridgeBodySet {

    public BridgeBodySetImpl() {
    }

    public BridgeBodySetImpl(Comparator<? super BridgeBody> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAction_ID( UniqueId ref_Action_ID ) throws XtumlException {
        for ( BridgeBody bridgebody : this ) bridgebody.setAction_ID( ref_Action_ID );
    }
    @Override
    public void setBrg_ID( UniqueId ref_Brg_ID ) throws XtumlException {
        for ( BridgeBody bridgebody : this ) bridgebody.setBrg_ID( ref_Brg_ID );
    }


    // selections
    @Override
    public BridgeSet R697_specifies_processing_for_Bridge() throws XtumlException {
        BridgeSet bridgeset = new BridgeSetImpl();
        for ( BridgeBody bridgebody : this ) bridgeset.add( bridgebody.R697_specifies_processing_for_Bridge() );
        return bridgeset;
    }
    @Override
    public BodySet R698_is_a_Body() throws XtumlException {
        BodySet bodyset = new BodySetImpl();
        for ( BridgeBody bridgebody : this ) bodyset.add( bridgebody.R698_is_a_Body() );
        return bodyset;
    }


    @Override
    public BridgeBody nullElement() {
        return BridgeBodyImpl.EMPTY_BRIDGEBODY;
    }

    @Override
    public BridgeBodySet emptySet() {
      return new BridgeBodySetImpl();
    }

    @Override
    public BridgeBodySet emptySet(Comparator<? super BridgeBody> comp) {
      return new BridgeBodySetImpl(comp);
    }

    @Override
    public BridgeBodySet value() {
        return this;
    }

    @Override
    public List<BridgeBody> elements() {
        return Arrays.asList(toArray(new BridgeBody[0]));
    }

}
